
API reference
========================

DeltaBot
--------------------------------

.. autoclass:: deltabot.bot.DeltaBot
    :members:

.. autoclass:: deltabot.commands.IncomingCommand
    :members:

.. autoclass:: deltabot.filters.Filters
    :members:

.. autoclass:: deltabot.bot.Replies
    :members:

.. autoclass:: deltabot.plugins.Plugins
    :members:

.. autoclass:: deltabot.hookspec
    :members:

Account (from deltachat package)
--------------------------------

.. autoclass:: deltachat.account.Account
    :members:


Message (from deltachat package)
--------------------------------

.. autoclass:: deltachat.message.Message
    :members:

Chat (from deltachat package)
--------------------------------

.. autoclass:: deltachat.chat.Chat
    :members:

Contact (from deltachat package)
--------------------------------

.. autoclass:: deltachat.contact.Contact
    :members:
